@@ -6,13 +6,14 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
 import (
 	"strings"
 
-	app "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
+	app "open-cluster-management.io/multicloud-operators-subscription/pkg/apis/apps/helmrelease/v1"
 )
 
 // AppHelmCRResource ...
