@@ -6,17 +6,18 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
 import (
 	"testing"
 
-	mcm "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/mcm/v1alpha1"
+	policy "github.com/stolostron/governance-policy-propagator/pkg/apis/policy/v1"
 )
 
 func TestTransformPlacementBinding(t *testing.T) {
-	var p mcm.PlacementBinding
+	var p policy.PlacementBinding
 	UnmarshalFile("placementbinding.json", &p, t)
 	node := PlacementBindingResourceBuilder(&p).BuildNode()
 
